proust_sentiments: Old sentiment lexicon This function has been deprecated, and...

View source: R/proust_sentiments.R

proust_sentimentsR Documentation

Old sentiment lexicon This function has been deprecated, and will be in next proustr version. See the rfeel package now: https://github.com/ColinFay/rfeel

Description

Old sentiment lexicon This function has been deprecated, and will be in next proustr version. See the rfeel package now: https://github.com/ColinFay/rfeel

Usage

proust_sentiments(type = c("polarity", "score"))

Arguments

type

For backward compatibility

Value

a tibble


proustr documentation built on Sept. 3, 2026, 5:09 p.m.