Learn R Programming

proustr (version 0.4.1)

proust_sentiments: Old sentiment lexicon This function has been deprecated, and will be in next proustr version. See the rfeel package now: https://github.com/ColinFay/rfeel

Description

Old sentiment lexicon This function has been deprecated, and will be in next proustr version. See the rfeel package now: https://github.com/ColinFay/rfeel

Usage

proust_sentiments(type = c("polarity", "score"))

Value

a tibble

Arguments

type

For backward compatibility